nvector._core.n_E2R_EN — nvector 0.7.5 documentation

# nvector._core.n_E2R_EN

`n_E2R_EN`(n_E, R_Ee=None)

  Returns the rotation matrix R_EN from n-vector.

  Parameters
    n_E: 3 x n array

      n-vector [no unit] decomposed in E

    R_Ee3 x 3 array

      rotation matrix defining the axes of the coordinate frame E.

  Returns
    R_EN: 3 x 3 x n array

      The resulting rotation matrix [no unit] (direction cosine matrix).

  See also

  `R_EN2n_E`, `n_E_and_wa2R_EL`, `R_EL2n_E`